:mod:`pyramid_nacl_session` API Reference
=========================================

.. automodule:: pyramid_nacl_session

   .. autoclass:: EncryptedSerializer

   .. autofunction:: EncryptedCookieSessionFactory

   .. autofunction:: generate_secret

   .. autofunction:: session_factory_from_settings
